<?php

namespace Drupal\infogram;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Template\TwigEnvironment;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Infogram helper service.
 */
class Infogram implements ContainerInjectionInterface {

  /**
   * Infogram constructor.
   *
   * @param \Drupal\Core\Template\TwigEnvironment $twig
   *   The Twig environment.
   * @param \Drupal\Core\Extension\ModuleExtensionList $extensionListModule
   *   The module extension list.
   */
  public function __construct(
    protected TwigEnvironment $twig,
    protected ModuleExtensionList $extensionListModule,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('twig'),
      $container->get('extension.list.module')
    );
  }

  /**
   * Render the inforgram embed code.
   *
   * @param string $id
   *   Identifier of infogram.
   * @param string $format
   *   Infogram's format.
   *
   * @return string
   *   Infogram embed code.
   *
   * @throws \Twig\Error\LoaderError
   * @throws \Twig\Error\RuntimeError
   * @throws \Twig\Error\SyntaxError
   */
  public function getEmbedCode(string $id, string $format = 'interactive'): string {
    $templatePath = $this->extensionListModule->getPath('infogram') . '/templates/infogram.html.twig';
    $template = $this->twig->load($templatePath);
    return $template->render([
      'data' => [
        'id' => $id,
        'format' => $format,
      ],
    ]);
  }

}
