<?php

namespace Drupal\infogram\Plugin\Filter;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;
use Drupal\infogram\Infogram;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Infogram WYSIWYG filter.
 *
 * @Filter(
 *   id = "filter_infogram",
 *   title = @Translation("Infogram embed codes"),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_TRANSFORM_IRREVERSIBLE,
 * )
 */
class FilterInfogram extends FilterBase implements ContainerFactoryPluginInterface {

  /**
   * Constructs a FilterInfogram object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\infogram\Infogram $infogram
   *   The entity repository.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, protected Infogram $infogram) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('infogram'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode): FilterProcessResult {

    $infogramParams = [];
    preg_match('/id="([^"]+)"[^]]*format="([^"]+)"/', $text, $infogramParams);

    if (count($infogramParams)) {
      $id = '';
      if (isset($infogramParams[1])) {
        $id = $infogramParams[1];
      }
      $format = $infogramParams[2] ?? 'interactive';
      $text = preg_replace('/\[infogram [^\]]*\]/', $this->infogram->getEmbedCode($id, $format), $text);
    }

    return new FilterProcessResult($text);
  }

}
